@@ -370,7 +370,7 @@ class KIRIGAMIPLATFORM_EXPORT PlatformTheme : public QObject
     Q_PROPERTY(QColor hoverColor READ hoverColor WRITE setCustomHoverColor RESET setCustomHoverColor NOTIFY colorsChanged FINAL)
 
     /*!
-     * \qmlattachedproperty color Theme::useAlternateBackgroundColor
+     * \qmlattachedproperty bool Theme::useAlternateBackgroundColor
      *
      * Hint for item views to actually make use of the alternate background color feature.
      */
@@ -597,6 +597,9 @@ Q_SIGNALS:
     void useAlternateBackgroundColorChanged(bool alternate);
 
 protected:
+    /// To set in the constructors so the changes trackers can avoid emitting
+    void setConstructing(bool isConstructing);
+
     // Setters, not accessible from QML but from implementations
     void setSupportsIconColoring(bool support);
 
